Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(84)

Unified Diff: chrome/browser/gpu_process_host_ui_shim.cc

Issue 6793054: Moved code that runs in both the browser and GPU process from content/gpu to content/common/gpu. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gpu_process_host_ui_shim.h ('k') | chrome/chrome_tests.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/gpu_process_host_ui_shim.cc
===================================================================
--- chrome/browser/gpu_process_host_ui_shim.cc (revision 80399)
+++ chrome/browser/gpu_process_host_ui_shim.cc (working copy)
@@ -70,7 +70,7 @@
DCHECK(!msg->is_sync());
#endif
// When the GpuRenderThread sends an IPC, post it to the UI thread without
// using IPC.
bool success = BrowserThread::PostTask(
BrowserThread::UI,
@@ -82,9 +82,9 @@
}
};
-void ForwardMessageToGpuThread(GpuRenderThread* render_thread,
+void ForwardMessageToGpuThread(GpuChannelManager* gpu_channel_manager,
IPC::Message* msg) {
- bool success = render_thread->OnMessageReceived(*msg);
+ bool success = gpu_channel_manager->OnMessageReceived(*msg);
// If the message was not handled, it is likely it was intended for the
// GpuChildThread, which does not exist in single process and in process GPU
@@ -162,7 +162,7 @@
GpuProcessHostUIShim::GpuProcessHostUIShim(int host_id)
: host_id_(host_id),
gpu_process_(base::kNullProcessHandle),
- gpu_render_thread_(NULL),
+ gpu_channel_manager_(NULL),
ui_thread_sender_(NULL) {
g_hosts_by_id.AddWithID(this, host_id_);
gpu_data_manager_ = GpuDataManager::GetInstance();
@@ -171,7 +171,7 @@
if (host_id == 0) {
gpu_process_ = base::GetCurrentProcessHandle();
ui_thread_sender_ = new UIThreadSender;
- gpu_render_thread_ = new GpuRenderThread(
+ gpu_channel_manager_ = new GpuChannelManager(
ui_thread_sender_,
NULL,
g_browser_process->io_thread()->message_loop(),
@@ -275,7 +275,7 @@
BrowserThread::GPU,
FROM_HERE,
NewRunnableFunction(ForwardMessageToGpuThread,
- gpu_render_thread_,
+ gpu_channel_manager_,
msg));
} else {
success = BrowserThread::PostTask(
@@ -485,11 +485,11 @@
#endif
// Ensure these are destroyed on the GPU thread.
- if (gpu_render_thread_) {
+ if (gpu_channel_manager_) {
BrowserThread::DeleteSoon(BrowserThread::GPU,
FROM_HERE,
- gpu_render_thread_);
- gpu_render_thread_ = NULL;
+ gpu_channel_manager_);
+ gpu_channel_manager_ = NULL;
}
if (ui_thread_sender_) {
BrowserThread::DeleteSoon(BrowserThread::GPU,
@@ -70,7 +70,7 @@
DCHECK(!msg->is_sync());
#endif
- // When the GpuRenderThread sends an IPC, post it to the UI thread without
+ // When the GpuChannelManager sends an IPC, post it to the UI thread without
// using IPC.
bool success = BrowserThread::PostTask(
« no previous file with comments | « chrome/browser/gpu_process_host_ui_shim.h ('k') | chrome/chrome_tests.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698